Domain
======

.. currentmodule:: pqp.data

.. autoclass:: Domain
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Domain.describe_assumptions
      ~Domain.get_cardinality
      ~Domain.validate
      ~Domain.validate_or_throw

   .. rubric:: Methods Documentation

   .. automethod:: describe_assumptions
   .. automethod:: get_cardinality
   .. automethod:: validate
   .. automethod:: validate_or_throw
